@@ -110,7 +110,7 @@ public class ImageConverterClient implements IImageClient {
         m_clientConfig = new ImageConverterClientConfig(configurationService);
 
         if (!m_clientConfig.isValid()) {
-            throw new OXException(new Throwable("Configuration service is available, but config property is not valid"));
+        	throw OXException.general("Configuration service is available, but config property is not valid");
         }
 
         m_apiProvider = new ImageConverterApiProvider(m_clientConfig);
@@ -132,12 +132,8 @@ public class ImageConverterClient implements IImageClient {
     public InputStream getImage(final String imageKey, final String requestFormat, final String... context) throws ImageConverterException {
         final ImageConverterApi api = m_apiProvider.acquire();
         InputStream ret = null;
-
-        if (LOG.isTraceEnabled()) {
-            LOG.trace(new StringBuilder("IC client #getImage called (imageKey/requestFormat): ").
-                append((null != imageKey) ? imageKey : "null").append(" / ").
-                append((null != requestFormat) ? requestFormat : "null").toString());
-        }
+        
+        LOG.trace("IC client #getImage called (imageKey/requestFormat): {} / {}", imageKey, requestFormat);
 
         if (null != api) {
             try {
@@ -172,10 +168,7 @@ public class ImageConverterClient implements IImageClient {
         final ImageConverterApi api = m_apiProvider.acquire();
         IMetadata ret = null;
 
-        if (LOG.isTraceEnabled()) {
-            LOG.trace(new StringBuilder("IC client #getMetadata called (imageKey): ").
-                append((null != imageKey) ? imageKey : "null").toString());
-        }
+        LOG.trace("IC client #getMetadata called (imageKey): {}", imageKey);
 
         if (null != api) {
             try {
@@ -216,11 +209,7 @@ public class ImageConverterClient implements IImageClient {
         final ImageConverterApi api = m_apiProvider.acquire();
         MetadataImage ret = null;
 
-        if (LOG.isTraceEnabled()) {
-            LOG.trace(new StringBuilder("IC client #getImageAndMetadata called (imageKey/requestFormat): ").
-                append((null != imageKey) ? imageKey : "null").append(" / ").
-                append((null != requestFormat) ? requestFormat : "null").toString());
-        }
+        LOG.trace("IC client #getImageAndMetadata called (imageKey/requestFormat): {} / {}", imageKey, requestFormat);
 
         if (null != api) {
             try {
@@ -256,10 +245,7 @@ public class ImageConverterClient implements IImageClient {
     public void cacheImage(final String imageKey, final InputStream srcImageStm, final String... context) throws ImageConverterException {
         final ImageConverterApi api = m_apiProvider.acquire();
 
-        if (LOG.isTraceEnabled()) {
-            LOG.trace(new StringBuilder("IC client #cacheImage called (imageKey/requestFormat): ").
-                append((null != imageKey) ? imageKey : "null").toString());
-        }
+        LOG.trace("IC client #cacheImage called (imageKey): {}", imageKey);
 
         if (null != api) {
             try {
@@ -292,11 +278,7 @@ public class ImageConverterClient implements IImageClient {
         final ImageConverterApi api = m_apiProvider.acquire();
         InputStream ret = null;
 
-        if (LOG.isTraceEnabled()) {
-            LOG.trace(new StringBuilder("IC client #cacheAndGetImage called (imageKey/requestFormat): ").
-                append((null != imageKey) ? imageKey : "null").append(" / ").
-                append((null != requestFormat) ? requestFormat : "null").toString());
-        }
+        LOG.trace("IC client #cacheAndGetImage called (imageKey/requestFormat): {} / {}", imageKey, requestFormat);
 
         if (null != api) {
             try {
@@ -342,11 +324,7 @@ public class ImageConverterClient implements IImageClient {
         final ImageConverterApi api = m_apiProvider.acquire();
         MetadataImage ret = null;
 
-        if (LOG.isTraceEnabled()) {
-            LOG.trace(new StringBuilder("IC client #cacheAndGetImageAndMetadata called (imageKey/requestFormat): ").
-                append((null != imageKey) ? imageKey : "null").append(" / ").
-                append((null != requestFormat) ? requestFormat : "null").toString());
-        }
+        LOG.trace("IC client #cacheAndGetImageAndMetadata called (imageKey/requestFormat): {} / {}", imageKey, requestFormat);
 
         if (null != api) {
             try {
@@ -391,9 +369,7 @@ public class ImageConverterClient implements IImageClient {
     public void clearImages(final String... context) throws ImageConverterException {
         final ImageConverterApi api = m_apiProvider.acquire();
 
-        if (LOG.isTraceEnabled()) {
-            LOG.trace("IC client #clearImages called");
-        }
+        LOG.trace("IC client #clearImages called");
 
         if (null != api) {
             try {
@@ -414,10 +390,7 @@ public class ImageConverterClient implements IImageClient {
     public void clearImagesByKey(final String imageKey) throws ImageConverterException {
         final ImageConverterApi api = m_apiProvider.acquire();
 
-        if (LOG.isTraceEnabled()) {
-            LOG.trace(new StringBuilder("IC client #clearImagesByKey called (imageKey): ").
-                append((null != imageKey) ? imageKey : "null").toString());
-        }
+        LOG.trace("IC client #clearImagesByKey called (imageKey): {}", imageKey);
 
         if (null != api) {
             try {
@@ -438,9 +411,7 @@ public class ImageConverterClient implements IImageClient {
         final ImageConverterApi api = m_apiProvider.acquire();
         long ret = 0;
 
-        if (LOG.isTraceEnabled()) {
-            LOG.trace("IC client #getKeyCount called");
-        }
+        LOG.trace("IC client #getKeyCount called");
 
         if (null != api) {
             try {
@@ -463,9 +434,7 @@ public class ImageConverterClient implements IImageClient {
         final ImageConverterApi api = m_apiProvider.acquire();
         String [] ret = {};
 
-        if (LOG.isTraceEnabled()) {
-            LOG.trace("IC client #getKeys called");
-        }
+        LOG.trace("IC client #getKeys called");
 
         if (null != api) {
             try {
@@ -495,19 +464,20 @@ public class ImageConverterClient implements IImageClient {
      * @throws WebServiceException
      */
     @Override
-    public String status() throws ImageConverterException {
+    public String status() throws OXException {
         final ImageConverterApi api = m_apiProvider.acquire();
         String ret = null;
 
-        if (LOG.isTraceEnabled()) {
-            LOG.trace("IC client #status called");
-        }
+        LOG.trace("IC client #status called");
 
         if (null != api) {
             try {
                 ret = api.status();
             } catch (ApiException e) {
-                implHandleAPIException("Error in remote calling ImageConverter#status", e);
+                ImageConverterException ice = implWrapAPIException("Error in remote calling ImageConverter#status", e);
+                if (ice != null) {
+                	throw OXException.general(ice.getMessage(), ice);
+                }
             } finally {
                 m_apiProvider.release(api);
             }
@@ -536,6 +506,13 @@ public class ImageConverterClient implements IImageClient {
     // - Implementation --------------------------------------------------------
 
     private void implHandleAPIException(final String msg, final ApiException e) throws ImageConverterException {
+    	final ImageConverterException ice = implWrapAPIException(msg, e);
+    	if (ice != null) {
+    		throw ice;
+    	}
+    }
+    
+    private ImageConverterException implWrapAPIException(final String msg, final ApiException e) {
         final StringBuilder throwMessageBuilder = new StringBuilder(StringUtils.isNotEmpty(msg) ? msg : "IC client received unknown API exception");
         boolean throwException = true;
 
@@ -547,9 +524,7 @@ public class ImageConverterClient implements IImageClient {
             if (Status.NOT_FOUND.getStatusCode() == statusCode) {
                 throwException = false;
 
-                if (LOG.isTraceEnabled()) {
-                    LOG.trace("IC client received a resource NOT_FOUND error from server => proceeding normally");
-                }
+                LOG.trace("IC client received a resource NOT_FOUND error from server => proceeding normally");
             } else {
                 if ((e.getCode() == 503) || (cause instanceof IOException) || StringUtils.containsIgnoreCase(causeMessage, "terminated")) {
                     m_remoteValidator.resetConnection();
@@ -559,13 +534,15 @@ public class ImageConverterClient implements IImageClient {
                         append(")").toString());
                 }
 
-                throw new ImageConverterException(throwMessageBuilder.toString(), e);
+                return new ImageConverterException(throwMessageBuilder.toString(), e);
             }
         }
 
         if (throwException) {
-            throw new ImageConverterException(throwMessageBuilder.toString());
+            return new ImageConverterException(throwMessageBuilder.toString());
         }
+        
+        return null;
     }
 
     /**
